@@ -2,6 +2,7 @@ import traceback
 
 import pandas as pd
 import pytest
+from pytest_html import extras
 from .drivers.browsers import browser_os_name_conf
 from .conf.rwd.Website import base_url_conf
 from .utils import html_report_conf
@@ -156,14 +157,16 @@ def testID(request):
 def non_breakable(request):
     "pytest fixture for app activity"
     try:
-        return request.config.getoption("--non_breakable")
+        if request.config.getoption("--non_breakable") == 'Y' or 'N':
+            return request.config.getoption("--non_breakable")
+        else:
+            raise Exception("Invalid value for -- non_breakable flag --- please enter Y or N")
 
     except Exception as e:
         print("Exception when trying to run test: %s" % __file__)
         print("Python says:%s" % str(e))
 
 
-
 @pytest.fixture
 def cases(request, product, testID):
     name = request.config.getoption("--xlsx")
@@ -211,6 +214,20 @@ def pytest_configure(config):
     config.addinivalue_line("markers", "MOBILE: mark a test as part of the GUI regression suite.")
 
 
+@pytest.hookimpl(hookwrapper=True)
+def pytest_runtest_makereport(item, call):
+    pytest_html = item.config.pluginmanager.getplugin("html")
+    outcome = yield
+    report = outcome.get_result()
+    extra = getattr(report, "extra", [])
+    if report.when == "call":
+        test_func = test_obj
+        screenshot_name = '%003d' % test_func.screenshot_counter + '' + test_func.name_
+        # extra.append(pytest_html.extras.url(test_obj.screenshot_dir, name="Screenshot Folder"))
+        filename = f'{screenshot_name}.png'
+        extra.append(pytest_html.extras.image(filename))
+        report.extra = extra
+
 @pytest.hookimpl(tryfirst=True)
 def pytest_configure(config):
     filename = 'report_' + datetime.now().strftime(
